# Release Notes
---

## [1.0.2](https://github.com/osl-incubator/makim/compare/1.0.1...1.0.2) (2023-01-26)


### Bug Fixes

* Fix support for Python 3.7.1, 3.8, 3.9, 3.10 ([#7](https://github.com/osl-incubator/makim/issues/7)) ([418f3de](https://github.com/osl-incubator/makim/commit/418f3de6dc4e5f1b963b32da9736163ea78ce5f5))

## [1.0.1](https://github.com/osl-incubator/makim/compare/1.0.0...1.0.1) (2023-01-25)


### Bug Fixes

* Suppress the sh traceback message error ([#5](https://github.com/osl-incubator/makim/issues/5)) ([dc3f4ad](https://github.com/osl-incubator/makim/commit/dc3f4ad1a949cd72e628742107cf5bd368721b7e))
